pub enum Size {
Inner,
Fill,
FillMinimum,
Percentage(Length<f32, ()>),
Pixels(Length<f32, ()>),
RootPercentage(Length<f32, ()>),
Fn(Box<SizeFn>),
Flex(Length<f32, ()>),
}Variants
Inner
Sizes the element based on its content. This is the default.
Can also be created with Size::auto.
let size = Size::auto();Fill
Expands to fill all the available space from its parent.
Can also be created with Size::fill.
let size = Size::fill();FillMinimum
Expand to the biggest sibling when using Content::fit.
Can also be created with Size::fill_minimum.
let size = Size::fill_minimum();Percentage(Length<f32, ()>)
Sizes as a percentage relative to the parent’s size.
Can also be created with Size::percent.
let size = Size::percent(50.0);Pixels(Length<f32, ()>)
RootPercentage(Length<f32, ()>)
Sizes as a percentage relative to the root (window) size.
Can also be created with Size::window_percent.
let size = Size::window_percent(80.0);Fn(Box<SizeFn>)
Dynamic size computed by a closure at layout time.
Can also be created with Size::func or Size::func_data.
Flex(Length<f32, ()>)
Flex grow factor, fills the available space proportionally in the final layout phase.
Can also be created with Size::flex.
let size = Size::flex(1.0);Implementations
Sourceimpl Size
impl Size
Sourcepub fn fill_minimum() -> Size
pub fn fill_minimum() -> Size
Use a FillMinimum size.
Sourcepub fn window_percent(percent: impl Into<f32>) -> Size
pub fn window_percent(percent: impl Into<f32>) -> Size
Use a RootPercentage size.
Sourcepub fn func(
func: impl Fn(SizeFnContext) -> Option<f32> + Sync + Send + 'static,
) -> Size
pub fn func( func: impl Fn(SizeFnContext) -> Option<f32> + Sync + Send + 'static, ) -> Size
Use a dynamic Fn size computed by the given closure.
Sourcepub fn func_data<D>(
func: impl Fn(SizeFnContext) -> Option<f32> + Sync + Send + 'static,
data: &D,
) -> Sizewhere
D: Hash,
pub fn func_data<D>(
func: impl Fn(SizeFnContext) -> Option<f32> + Sync + Send + 'static,
data: &D,
) -> Sizewhere
D: Hash,
Use a dynamic Fn size with hashable data for equality checks.
pub fn pretty(&self) -> String