pub enum Alignment {
Start,
Center,
End,
SpaceBetween,
SpaceEvenly,
SpaceAround,
}Variants
Start
Align children to the start of the axis. This is the default.
Center
Align children to the center of the axis.
End
Align children to the end of the axis.
SpaceBetween
Distribute children with equal space between them, no space at the edges.
SpaceEvenly
Distribute children with equal space between and around them, including the edges.
SpaceAround
Distribute children with equal space around them, half-size space at the edges.
Implementations
Sourceimpl Alignment
impl Alignment
Sourcepub fn space_between() -> Alignment
pub fn space_between() -> Alignment
Use a SpaceBetween alignment.
Sourcepub fn space_evenly() -> Alignment
pub fn space_evenly() -> Alignment
Use a SpaceEvenly alignment.
Sourcepub fn space_around() -> Alignment
pub fn space_around() -> Alignment
Use a SpaceAround alignment.
pub const fn is_not_start(&self) -> bool
pub const fn is_spaced(&self) -> bool
pub fn pretty(&self) -> String